A package to save and load dictionaries containing multiple Pandas dataframes to/from a tar file.

D. Estes McKnight, 2022.

Created off the back of Rob deCarvalho's method to save a dict of dataframes to a tar file. (https://gist.github.com/robdmc/56c998bfafb8f1037744e6493238768e)
